ImageFormat

Enum ImageFormat 

#[non_exhaustive]
pub enum ImageFormat { None = 0, Bmp = 1, Gif = 2, Png = 3, Apng = 4, Jpeg = 5, Pnm = 6, }
Indicates the file format the image used (when loading it) or will use (when storing it).

For more information, see the libplum’s Supported file formats page.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

No image type.

Used by an image for which an image type hasn’t been specified, such as one just created by DirectImage::new_zeroed(). It may also be used as an explicit “no type” designator.



Bmp = 1

BMP (Windows Bitmap) file.



Gif = 2

GIF (CompuServe’s Graphics Interchange Format) format, including both static images and animations.



Png = 3

PNG (Portable Network Graphics) file.



Apng = 4

Animated PNG file.

Treated as a separate format because it is not actually compatible with PNG (due to using ancillary chunks to store critical animation information), which will cause APNG-unaware viewers and editors to handle it incorrectly.



Jpeg = 5

JPEG (Joint Photographers Expert Group) file.



Pnm = 6

netpbm’s PNM (Portable Anymap) format.

When loading, it represents any possible PNM file; however, only PPM and PAM files will be written.