Frame

Struct Frame 

pub struct Frame<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized>(/* private fields */);
A reference to a specific frame of an image.

Implementations

Source

impl<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized> Frame<'img, Fmt, Img>

pub fn new(img: &'img Img, frame_idx: usize) -> Self

Creates a reference to img’s frame_idxth frame.

img.frame(frame_idx) may be more concise, if it’s available.

pub fn image(&self) -> &'img Img

Retrieves a reference to the image that this frame is part of.

pub fn pixel(&self, x: usize, y: usize) -> Fmt

Retrieves a copy of the pixel at the given coordinates.