FrameMut

Struct FrameMut 

pub struct FrameMut<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized>(/* private fields */);
A mutable reference to a specific frame of an image.

Implementations

Source

impl<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized> FrameMut<'img, Fmt, Img>

pub fn new(img: &'img mut Img, frame_idx: usize) -> Self

Creates a reference to img’s frame_idxth frame.

img.frame_mut(frame_idx) may be more concise, if it’s available.

pub fn image(&self) -> &Img

Retrieves a reference to the image that this frame is part of.

pub fn image_mut(&'img mut self) -> &'img mut Img

Retrieves a mutable reference to the image that this frame is part of.

pub fn pixel(&self, x: usize, y: usize) -> Fmt

Retrieves a copy of the pixel at the given coordinates.