pub struct FrameMut<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized>(/* private fields */);Expand description
A mutable reference to a specific frame of an image.
Implementations
Sourceimpl<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized> FrameMut<'img, Fmt, Img>
impl<'img, Fmt: ColorFmt, Img: Image<Fmt> + ?Sized> FrameMut<'img, Fmt, Img>
Sourcepub fn new(img: &'img mut Img, frame_idx: usize) -> Self
pub fn new(img: &'img mut Img, frame_idx: usize) -> Self
Creates a reference to img’s frame_idxth frame.
img.frame_mut(frame_idx) may be more concise, if it’s available.
Sourcepub fn image_mut(&'img mut self) -> &'img mut Img
pub fn image_mut(&'img mut self) -> &'img mut Img
Retrieves a mutable reference to the image that this frame is part of.